/****************************************************************/
/*                                                              */
/*            Advanced Navigation Kinematica API v1.2           */
/*              Copyright 2018, Advanced Navigation             */
/*                                                              */
/****************************************************************/
/*
 * Copyright (C) 2018 Advanced Navigation
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

package com.advancednavigation.kinematica.api.data;

public class Configuration
{
	// Configuration Options
	// Device IDs
	public static enum DeviceId
	{
		DEFAULT,                    // 0
		SPATIAL,                    // 1
		PRODUCTION_SYSTEM,          // 2
		ORIENTUS,                   // 3
		SPATIAL_FOG,                // 4
		SPATIAL_DUAL,               // 5
		SUBLOCUS,                   // 6
		SUBLOCUS_DVL,               // 7
		SPORTS_TRACKER,             // 8
		SUBLOCUS_DVL_RTI,           // 9
		ORIENTUS_V3,                // 10
		INTERFACE_AND_LOGGING_UNIT, // 11
		AIR_DATA_UNIT,              // 12
		SUBSONUS,                   // 13
		UWB_ANCHOR,                 // 14
		SPATIAL_FOG_DUAL,           // 15
		MOTUS                       // 16
	};

	// GnssOffsetSource, OdometerOffsetSource and DualAntennaOffsetSource Options
	public static int MANUAL_SOURCE = 0;
	public static int AUTOMATIC_SOURCE = 1;

	// DualAntennaOffsetType Options
	public static int MANUAL_OFFSET = 0;
	public static int AUTOMATIC_OFFSET = 1;

	// Dual Antenna Automatic Offset Options
	public static int PRIMARY_FRONT_AND_SECONDARY_REAR = 0;
	public static int PRIMARY_REAR_AND_SECONDARY_FRONT = 1;
	public static int PRIMARY_RIGHT_AND_SECONDARY_LEFT = 2;
	public static int PRIMARY_LEFT_AND_SECONDARY_RIGHT = 3;

	// #####################################################

	// Configuration fields
	public DeviceId deviceId;
	public String baseStationAntenna;
	public String roverAntenna;

	public int gnssOffsetSource;
	public double[] gnssOffset;

	public int odometerOffsetSource;
	public double[] odometerOffset;

	public int dualAntennaOffsetSource;
	public int dualAntennaOffsetType;
	public double[] dualAntennaManualOffset;
	public int dualAntennaAutomaticOffset;

	public int referencePointOffsetSource;
	public double[] referencePointOffset;

	public Configuration()
	{
		this.deviceId                   = DeviceId.DEFAULT;
		this.baseStationAntenna         = "Automatically select using RINEX file";
		this.roverAntenna               = "Automatically select using RINEX file";
		this.gnssOffsetSource           = AUTOMATIC_SOURCE;
		this.gnssOffset                 = new double[3];
		this.odometerOffsetSource       = AUTOMATIC_SOURCE;
		this.odometerOffset             = new double[3];
		this.dualAntennaOffsetSource    = AUTOMATIC_SOURCE;
		this.dualAntennaOffsetType      = MANUAL_OFFSET;
		this.dualAntennaManualOffset    = new double[3];
		this.dualAntennaAutomaticOffset = PRIMARY_FRONT_AND_SECONDARY_REAR;
		this.referencePointOffsetSource = AUTOMATIC_SOURCE;
		this.referencePointOffset       = new double[3];
	}

}
