/****************************************************************/
/*                                                              */
/*            Advanced Navigation Kinematica API v1.2           */
/*              Copyright 2018, Advanced Navigation             */
/*                                                              */
/****************************************************************/
/*
 * Copyright (C) 2018 Advanced Navigation
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

package com.advancednavigation.kinematica.api.json;

import java.io.StringReader;
import java.util.ArrayList;

import javax.json.Json;
import javax.json.JsonArray;
import javax.json.JsonArrayBuilder;
import javax.json.JsonObject;
import javax.json.JsonObjectBuilder;
import javax.json.JsonReader;

public class DataSetJSON
{
	public int id;
	public String name;
	public ArrayList<String> primaryFiles;
	public ArrayList<String> secondaryFiles;
	public int baseStationSource;
	public int ephemerisSource;
	public boolean sendEmail;

	public DataSetJSON(int id, String name,
			ArrayList<String> primaryFiles, ArrayList<String> secondaryFiles,
			int baseStationSource, int ephemerisSource,
			boolean sendEmail)
	{
		this.id                = id;
		this.name              = name;
		this.primaryFiles      = primaryFiles;
		this.secondaryFiles    = secondaryFiles;
		this.baseStationSource = baseStationSource;
		this.ephemerisSource   = ephemerisSource;
		this.sendEmail         = sendEmail;
	}

	public static DataSetJSON fromJson(String dataSetJson)
	{
		JsonReader jsonReader = Json.createReader(new StringReader(dataSetJson));
		JsonObject dataSetObject = jsonReader.readObject();
		jsonReader.close();

		int dataSetId = dataSetObject.getInt("id");
		String name = dataSetObject.getString("name");

		ArrayList<String> primaryFiles = new ArrayList<String>();
		JsonArray primaryFilesArray = dataSetObject.getJsonArray("primaryFiles");
		for (int i = 0; i < primaryFilesArray.size(); i++)
		{
			primaryFiles.add(primaryFilesArray.getString(i));
		}

		ArrayList<String> secondaryFiles = new ArrayList<String>();
		JsonArray secondaryFilesArray = dataSetObject.getJsonArray("secondaryFiles");
		for (int i = 0; i < secondaryFilesArray.size(); i++)
		{
			secondaryFiles.add(secondaryFilesArray.getString(i));
		}

		int baseStationSource = dataSetObject.getInt("baseStationSource");
		int ephemerisSource = dataSetObject.getInt("ephemerisSource");
		boolean sendEmail = dataSetObject.getBoolean("sendEmail");

		return new DataSetJSON(dataSetId, name, primaryFiles, secondaryFiles, baseStationSource, ephemerisSource, sendEmail);
	}

	public static String toJson(DataSetJSON dataSet)
	{
		JsonObjectBuilder builder = Json.createObjectBuilder();
		builder.add("id", dataSet.id);
		builder.add("name", dataSet.name);

		JsonArrayBuilder primaryFilesArray = Json.createArrayBuilder();
		for (String primaryFile : dataSet.primaryFiles)
		{
			primaryFilesArray.add(primaryFile);
		}
		builder.add("primaryFiles", primaryFilesArray);

		JsonArrayBuilder secondaryFilesArray = Json.createArrayBuilder();
		for (String secondaryFile : dataSet.secondaryFiles)
		{
			secondaryFilesArray.add(secondaryFile);
		}
		builder.add("secondaryFiles", secondaryFilesArray);

		builder.add("baseStationSource", dataSet.baseStationSource);
		builder.add("ephemerisSource", dataSet.ephemerisSource);
		builder.add("sendEmail", dataSet.sendEmail);
		
		JsonObject dataSetObject = builder.build();

		return dataSetObject.toString();
	}

}
