/****************************************************************/
/*                                                              */
/*            Advanced Navigation Kinematica API v1.2           */
/*              Copyright 2018, Advanced Navigation             */
/*                                                              */
/****************************************************************/
/*
 * Copyright (C) 2018 Advanced Navigation
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

package com.advancednavigation.kinematica.api.json;

import java.io.StringReader;

import javax.json.Json;
import javax.json.JsonObject;
import javax.json.JsonObjectBuilder;
import javax.json.JsonReader;

public class StatusJSON
{
	public String status;
	public int currentProgress; // 0 .. 100
	public int totalProgress;   // 0 .. 100
	public boolean processing;

	public StatusJSON(String status, int currentProgress, int totalProgress, boolean processing)
	{
		this.status          = status;
		this.currentProgress = currentProgress;
		this.totalProgress   = totalProgress;
		this.processing      = processing;
	}

	public static StatusJSON fromJson(String statusJson)
	{
		JsonReader jsonReader   = Json.createReader(new StringReader(statusJson));
		JsonObject statusObject = jsonReader.readObject();
		jsonReader.close();

		String status       = statusObject.getString("status");
		int currentProgress = statusObject.getInt("currentProgress");
		int totalProgress   = statusObject.getInt("totalProgress");
		boolean processing  = statusObject.getBoolean("processing");

		return new StatusJSON(status, currentProgress, totalProgress, processing);
	}

	public static String toJson(StatusJSON status)
	{
		JsonObjectBuilder builder = Json.createObjectBuilder();
		builder.add("status", status.status);
		builder.add("currentProgress", status.currentProgress);
		builder.add("totalProgress", status.totalProgress);
		builder.add("processing", status.processing);

		JsonObject statusObject = builder.build();

		return statusObject.toString();
	}

}
